@@ -3,6 +3,9 @@ Python envelope for the popular C library libjpeg for handling JPEG files.
 
 It offers full control over compression and decompression
 and exposes DCT coefficients and quantization tables.
+
+Author: Martin Benes
+Affiliation: Universitaet Innsbruck
 """
 
 # functions
@@ -12,11 +15,19 @@ from .functional import read_dct, read_spatial, from_spatial, from_dct
 from .dct_jpeg import DCTJPEG, DCTJPEGio, to_jpegio
 from .spatial_jpeg import SpatialJPEG
 
-# cstructs
-from ._colorspace import Colorspace
-from ._dctmethod import DCTMethod
-from ._dithermode import Dithermode
+# cenums
+from ._cenum import Colorspace, DCTMethod, Dithermode, MarkerType
 from ._marker import Marker
+# cenum abbreviations
+JCS_UNKNOWN = Colorspace.JCS_UNKNOWN
+JCS_GRAYSCALE = Colorspace.JCS_GRAYSCALE
+JCS_RGB = Colorspace.JCS_RGB
+JCS_YCbCr = Colorspace.JCS_YCbCr
+JCS_CMYK = Colorspace.JCS_CMYK
+JCS_YCCK = Colorspace.JCS_YCCK
+JDCT_ISLOW = DCTMethod.JDCT_ISLOW
+JDCT_IFAST = DCTMethod.JDCT_IFAST
+JDCT_FLOAT = DCTMethod.JDCT_FLOAT
 
 # libjpeg versions
 from .version import version
@@ -42,7 +53,7 @@ except IndexError:
 __all__ = [
     'read_dct', 'read_spatial', 'from_spatial', 'from_dct', 'to_jpegio',
     'SpatialJPEG', 'DCTJPEG', 'DCTJPEGio',
-    'Colorspace', 'DCTMethod', 'Dithermode', 'Marker',
+    'Colorspace', 'DCTMethod', 'Dithermode', 'Marker', 'MarkerType',
     'version', 'Jab_to_factors',
     '__version__',
 ]
