@@ -1,4 +1,8 @@
+"""
 
+Author: Martin Benes
+Affiliation: Universitaet Innsbruck
+"""
 
 from __future__ import annotations
 import dataclasses
@@ -7,6 +11,7 @@ import numpy as np
 
 @dataclasses.dataclass
 class Huffman:
+    """"""
     bits: np.ndarray
     """bits used to represent number of elements"""
     values: np.ndarray
